#!/usr/bin/env python2
# -*- coding: utf-8 -*-
"""
Created on Mon May  7 15:02:30 2018

@author: mischaknabenhans
"""

#%% Import modules
import numpy as np
from scipy.ndimage import convolve
import matplotlib.pyplot as plt
from matplotlib.animation import FuncAnimation

#%% Experimental setup
a = -1.0
dt = 0.3
dx = 1.0

Nmax = 1000
tmax = (Nmax-1)*dt

nxGrid = 1000
xGrid = np.linspace(0,(nxGrid-1)*dx,nxGrid)

UpwindKernel = np.array([0,1+dt/dx*a,-dt/dx*a])

#%% Prerequisites for animation plot

fig, ax = plt.subplots()
ax.set_xlim(xGrid[0],xGrid[-1])
ax.set_ylim(0, 1.0)
ax.set_xlabel("L")
ax.set_ylabel("u")
ln, = plt.plot([], [], animated=True)

#%% Define initial condition
u = np.zeros_like(xGrid)
u[:100] = 1


#%% Evolution
def update(frame):
    global u,xGrid,UpwindKernel 
    u=convolve(u,UpwindKernel,mode='wrap')

    ln.set_data(xGrid,u)
    return ln,

#%% Plot
ani = FuncAnimation(fig, update, frames=np.linspace(0, tmax, Nmax),
                    init_func=None, blit=True, interval=1)
plt.show()